package com.zg.project.information.service.impl;

import java.util.List;

import com.zg.project.information.domain.SceneMapping;
import com.zg.project.information.mapper.SceneMappingMapper;
import com.zg.project.information.service.ISceneMappingService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

/**
 * 场景编号Service业务层处理
 * 
 * @author zg
 * @date 2025-05-24
 */
@Service
public class SceneMappingServiceImpl implements ISceneMappingService
{
    @Autowired
    private SceneMappingMapper sceneMappingMapper;

    /**
     * 查询场景编号
     * 
     * @param id 场景编号主键
     * @return 场景编号
     */
    @Override
    public SceneMapping selectSceneMappingById(Long id)
    {
        return sceneMappingMapper.selectSceneMappingById(id);
    }

    /**
     * 查询场景编号列表
     * 
     * @param sceneMapping 场景编号
     * @return 场景编号
     */
    @Override
    public List<SceneMapping> selectSceneMappingList(SceneMapping sceneMapping)
    {
        return sceneMappingMapper.selectSceneMappingList(sceneMapping);
    }

    /**
     * 新增场景编号
     * 
     * @param sceneMapping 场景编号
     * @return 结果
     */
    @Override
    public int insertSceneMapping(SceneMapping sceneMapping)
    {
        return sceneMappingMapper.insertSceneMapping(sceneMapping);
    }

    /**
     * 修改场景编号
     * 
     * @param sceneMapping 场景编号
     * @return 结果
     */
    @Override
    public int updateSceneMapping(SceneMapping sceneMapping)
    {
        return sceneMappingMapper.updateSceneMapping(sceneMapping);
    }

    /**
     * 批量删除场景编号
     * 
     * @param ids 需要删除的场景编号主键
     * @return 结果
     */
    @Override
    public int deleteSceneMappingByIds(Long[] ids)
    {
        return sceneMappingMapper.deleteSceneMappingByIds(ids);
    }

    /**
     * 删除场景编号信息
     * 
     * @param id 场景编号主键
     * @return 结果
     */
    @Override
    public int deleteSceneMappingById(Long id)
    {
        return sceneMappingMapper.deleteSceneMappingById(id);
    }
}
